@@ -22,6 +22,8 @@ import binascii
 import logging
 import threading
 
+from multiprocessing import process as _mproc
+
 from .compat import bytes
 try:
     from _weakrefset import WeakSet
@@ -46,6 +48,11 @@ def current_process():
     return _current_process
 
 
+def _set_current_process(process):
+    global _current_process
+    _current_process = _mproc._current_process = process
+
+
 def _cleanup():
     # check for processes which have finished
     if _current_process is not None:
@@ -254,7 +261,7 @@ class Process(object):
                 except (OSError, ValueError):
                     pass
             old_process = _current_process
-            _current_process = self
+            _set_current_process(self)
 
             # Re-init logging system.
             # Workaround for http://bugs.python.org/issue6721/#msg140215
